#!/usr/bin/env python
# -*- coding: utf-8; py-indent-offset:4 -*-

from __future__ import absolute_import, division, print_function, unicode_literals

import os

if directory is None:
    directory = os.getcwd()


# For testing
directory = '/home/carter/Documents/TAcharts/TAcharts'

myfiles = os.listdir(directory)
myfile = myfiles[0]

pyfile = os.getcwd() + '/' + myfile

foo(pyfile)



os.getcwd()


list(filter(foo, myfiles))

os.path.isfile(pyfile)



def foo(pyfile):

    if '__init__' not in pyfile and 'py' in pyfile:
        if os.path.isdir(pyfile):
            return f'from . import {pyfile} as {pyfile}'
        elif os.path.isfile(pyfile):
            return f'from .{pyfile[:pyfile.find(".")]} import *'
        else:
            return f'This file is not recognized as a file or directory:  {pyfile}'
            # Timestamp of Easter Egg: 2019.01.08 1:54am
            raise AssertionError(f'Error: Call Carter at (916) 477-5363 for further instruction')




def loop_through_directory(directory):

    statements = [f'from .{filename[:filename.find(".")]} import *' \
                for filename in sorted(os.listdir(directory)) \
                # only look at python files that are not __init__ files
                if 'py' in filename \
                and '__init__' not in filename \
                and os.path.isfile(directory + '/' + filename)]

    return statements


# Code to auto-generate import files
myList = loop_through_directory(os.getcwd())

with open(os.getcwd() + '/' + '__init__.py', 'w') as pyfile:
    pyfile.write('\n'.join(myList))



#!/usr/bin/env python
# -*- coding: utf-8; py-indent-offset:4 -*-
from __future__ import absolute_import, division, print_function, unicode_literals

from TAcharts.utils.group_candles import group_candles

from .sma import sma
from .sdev import sdev

import pandas as pd
import os


class Bollinger:

    def __init__(self, df, date=None, filename=None, interval=None, n=14):

        if filename:
            filename_abs_path = f'{os.getcwd()}/{filename}'
            try:
                df = pd.read_csv(filename_abs_path)
            except:
                raise FileNotFoundError(f'{filename_abs_path}\n\nDoes not exist.')
        elif df is None:
            df = demo_df

        # Make all columns lowercase
        df.columns = [col.lower() for col in df]

        if interval:
            df = group_candles(df, interval)

        self._validate_data(df, n)

        df['date'] = df['date'].shift(1)
        self.df = df
        return


    def _validate_data(self, df, n):
        ''' Make sure we have more rows of data than the rolling average size '''

        if len(df) < n:
            raise AssertionError('Moving average cannot be larger than number of records.')


    def build(self, n=20, ndev=2):

        self.n = n
        self.ndev = ndev
        self.bollinger = {}

        # Create base simple moving average
        self.bollinger['sma'] = sma(df['close'], n=n)

        rng = ndev * sdev(df['close'], n=n)

        # Create upper and lower bands
        self.bollinger['h_band'] = self.bollinger['sma'] + rng
        self.bollinger['l_band'] = self.bollinger['sma'] - rng

        return self.bollinger
